@@ -309,6 +309,19 @@ class DeliverySqlServerTests(DataframeTestCase):
             expected_data=expectedData,
         )
 
+    def test20_big_data_set(self):
+        # Ensure table creation
+        self.sql_server.drop_table_by_name(self.table_name)
+        self.create_test_table()
+
+        # Create test data
+        df = self.create_data()
+
+        # Write as big data set
+        self.sql_server.write_table_by_name(df, self.table_name, big_data_set=True)
+        df_with_data = self.sql_server.read_table_by_name(self.table_name)
+        self.assertEqual(df_with_data.count(), 1)
+
     def create_test_table(self):
         sql_argument = f"""
             IF OBJECT_ID('{self.table_name}', 'U') IS NULL
